@@ -8,6 +8,9 @@ from dataclasses import dataclass
 from enum import Enum
 import json
 import requests
+import pandas as pd
+import os
+import time
 from typing import Optional, Dict, List, Union, Tuple
 from mlplatform_lib.utils.dataclass_utils import from_dict
 
@@ -141,6 +144,21 @@ class HyperdataHttpClient:
             do_list.append(self.get_do_info(auth, do_info["id"]))
         return do_list
 
+    def get_do_simple_list(self, auth: HyperdataUserAuth) ->dict:
+        res = self.send_request(
+            "mllabExperimentDataObject",
+            {},
+            {},
+            {},
+            auth,
+            HyperdataRequestType.READ
+        )
+        result = []
+        do_list = res.json()
+        for do in do_list["dto"]["dataOjbecdtInfoList"]:
+            result[do["name"]] = do["id"]
+        return result
+
     def get_do_info(self, auth: HyperdataUserAuth, do_id: int) -> DataObject:
         result = self.send_request(
             "", {"dataobjects": do_id}, {"action": "Detail"}, {}, auth, HyperdataRequestType.READ,
@@ -189,6 +207,34 @@ class HyperdataHttpClient:
         )
         return from_dict(TableDescInfo, result.data["dto"])
 
+    def get_do_to_csv(
+        self,
+        experiment_id: str,
+        do_id: str,
+        char_encoding: str,
+        full_path: str,
+        auth: HyperdataUserAuth
+    ) -> pd.DataFrame:
+        res = self.send_request(
+            "dataobjects",
+            {},
+            {"action" : "OutputFileDir"},
+            {"dataobjectId" : do_id, "experimentId" : experiment_id},
+            auth,
+            HyperdataRequestType.UPDATE
+        )
+        if res.status_code == 200:
+            print("Success")
+            while os.path.exists(full_path) is False:
+                print("Waiting")
+                time.sleep(0.1)
+            result = pd.read_csv(full_path, encoding=char_encoding)
+        else:
+            print("Fail")
+            print(res.json())
+            result = None
+        return result
+
     def download_do_to_csv(
         self, auth: HyperdataUserAuth, do_id: int
     ) -> Tuple[HyperdataRequestResult, str, str]:
