@@ -129,7 +129,7 @@ class MlPlatformHttpClient:
         train_id: int,
         model_id: int,
         model_info: ModelInfoDto,
-        auth: MlPlatformUserAuth
+        auth: MlPlatformUserAuth,
     ) -> ModelInfoDto:
         model_info.finished_time = datetime.now().strftime(MLPLATFORM_TIMSTAMP_FORMAT)
 
@@ -139,6 +139,6 @@ class MlPlatformHttpClient:
             {},
             to_dict(model_info),
             auth,
-            MlPlatformRequestType.CREATE
+            MlPlatformRequestType.CREATE,
         )
         return from_dict(ModelInfoDto, result.data)
